pub async fn start_udp_echo() -> (SocketAddr, JoinHandle<()>)Expand description
Start a UDP echo server that echoes received packets back to the sender.
Returns the listening address and a join handle.
pub async fn start_udp_echo() -> (SocketAddr, JoinHandle<()>)Start a UDP echo server that echoes received packets back to the sender.
Returns the listening address and a join handle.