pub async fn start_half_close_server() -> (SocketAddr, JoinHandle<()>)Expand description
Start a half-close server: reads until EOF, then sends a response and closes.
Returns the address the server is listening on and a join handle.
pub async fn start_half_close_server() -> (SocketAddr, JoinHandle<()>)Start a half-close server: reads until EOF, then sends a response and closes.
Returns the address the server is listening on and a join handle.