pub async fn start_echo_server() -> (SocketAddr, JoinHandle<()>)Expand description
Start an async echo server that echoes back received bytes.
Returns the address the server is listening on and a join handle.
pub async fn start_echo_server() -> (SocketAddr, JoinHandle<()>)Start an async echo server that echoes back received bytes.
Returns the address the server is listening on and a join handle.